@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2022 Greg Albrecht <oss@undef.net>
+# Copyright 2023 Greg Albrecht <oss@undef.net>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,10 @@
 # Author:: Greg Albrecht W2GMD <oss@undef.net>
 #
 
-"""
-ADS-B Cursor-On-Target Gateway.
-~~~~
+"""ADS-B Cursor on Target Gateway.
 
 :author: Greg Albrecht W2GMD <oss@undef.net>
-:copyright: Copyright 2022 Greg Albrecht
+:copyright: Copyright 2023 Greg Albrecht
 :license: Apache License, Version 2.0
 :source: <https://github.com/ampledata/adsbcot>
 """
@@ -38,5 +36,5 @@ from .functions import adsb_to_cot, create_tasks  # NOQA
 from .classes import ADSBWorker, ADSBNetReceiver, ADSBNetWorker  # NOQA
 
 __author__ = "Greg Albrecht W2GMD <oss@undef.net>"
-__copyright__ = "Copyright 2022 Greg Albrecht"
+__copyright__ = "Copyright 2023 Greg Albrecht"
 __license__ = "Apache License, Version 2.0"
